==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/WsfcDomainCredentialsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Domain credentials for setting up Windows Server Failover Cluster for SQL availability group.
 * @property clusterBootstrapAccountPassword Cluster bootstrap account password.
 * @property clusterOperatorAccountPassword Cluster operator account password.
 * @property sqlServiceAccountPassword SQL service account password.
 */
public data class WsfcDomainCredentialsArgs(
    public val clusterBootstrapAccountPassword: Output<String>? = null,
    public val clusterOperatorAccountPassword: Output<String>? = null,
    public val sqlServiceAccountPassword: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs.builder()
            .clusterBootstrapAccountPassword(clusterBootstrapAccountPassword?.applyValue({ args0 -> args0 }))
            .clusterOperatorAccountPassword(clusterOperatorAccountPassword?.applyValue({ args0 -> args0 }))
            .sqlServiceAccountPassword(sqlServiceAccountPassword?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WsfcDomainCredentialsArgs].
 */
@PulumiTagMarker
public class WsfcDomainCredentialsArgsBuilder internal constructor() {
    private var clusterBootstrapAccountPassword: Output<String>? = null

    private var clusterOperatorAccountPassword: Output<String>? = null

    private var sqlServiceAccountPassword: Output<String>? = null

    /**
     * @param value Cluster bootstrap account password.
     */
    @JvmName("btkbrfuaiqiyofyr")
    public suspend fun clusterBootstrapAccountPassword(`value`: Output<String>) {
        this.clusterBootstrapAccountPassword = value
    }

    /**
     * @param value Cluster operator account password.
     */
    @JvmName("hcjekfwpxqlfhjoc")
    public suspend fun clusterOperatorAccountPassword(`value`: Output<String>) {
        this.clusterOperatorAccountPassword = value
    }

    /**
     * @param value SQL service account password.
     */
    @JvmName("enbrpamqkctlimck")
    public suspend fun sqlServiceAccountPassword(`value`: Output<String>) {
        this.sqlServiceAccountPassword = value
    }

    /**
     * @param value Cluster bootstrap account password.
     */
    @JvmName("pyjrsnavaxnubmov")
    public suspend fun clusterBootstrapAccountPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterBootstrapAccountPassword = mapped
    }

    /**
     * @param value Cluster operator account password.
     */
    @JvmName("pmpvbapvcliwnctu")
    public suspend fun clusterOperatorAccountPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterOperatorAccountPassword = mapped
    }

    /**
     * @param value SQL service account password.
     */
    @JvmName("skuwoodndvbjmukp")
    public suspend fun sqlServiceAccountPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlServiceAccountPassword = mapped
    }

    internal fun build(): WsfcDomainCredentialsArgs = WsfcDomainCredentialsArgs(
        clusterBootstrapAccountPassword = clusterBootstrapAccountPassword,
        clusterOperatorAccountPassword = clusterOperatorAccountPassword,
        sqlServiceAccountPassword = sqlServiceAccountPassword,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/WsfcDomainCredentialsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Domain credentials for setting up Windows Server Failover Cluster for SQL availability group.
 * @property clusterBootstrapAccountPassword Cluster bootstrap account password.
 * @property clusterOperatorAccountPassword Cluster operator account password.
 * @property sqlServiceAccountPassword SQL service account password.
 */
public data class WsfcDomainCredentialsArgs(
    public val clusterBootstrapAccountPassword: Output<String>? = null,
    public val clusterOperatorAccountPassword: Output<String>? = null,
    public val sqlServiceAccountPassword: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs.builder()
            .clusterBootstrapAccountPassword(clusterBootstrapAccountPassword?.applyValue({ args0 -> args0 }))
            .clusterOperatorAccountPassword(clusterOperatorAccountPassword?.applyValue({ args0 -> args0 }))
            .sqlServiceAccountPassword(sqlServiceAccountPassword?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WsfcDomainCredentialsArgs].
 */
@PulumiTagMarker
public class WsfcDomainCredentialsArgsBuilder internal constructor() {
    private var clusterBootstrapAccountPassword: Output<String>? = null

    private var clusterOperatorAccountPassword: Output<String>? = null

    private var sqlServiceAccountPassword: Output<String>? = null

    /**
     * @param value Cluster bootstrap account password.
     */
    @JvmName("umdewecqltmxkkbu")
    public suspend fun clusterBootstrapAccountPassword(`value`: Output<String>) {
        this.clusterBootstrapAccountPassword = value
    }

    /**
     * @param value Cluster operator account password.
     */
    @JvmName("vtdyawjpogvybkag")
    public suspend fun clusterOperatorAccountPassword(`value`: Output<String>) {
        this.clusterOperatorAccountPassword = value
    }

    /**
     * @param value SQL service account password.
     */
    @JvmName("kyycqbchvtpljwve")
    public suspend fun sqlServiceAccountPassword(`value`: Output<String>) {
        this.sqlServiceAccountPassword = value
    }

    /**
     * @param value Cluster bootstrap account password.
     */
    @JvmName("eyhscxoiguslimox")
    public suspend fun clusterBootstrapAccountPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterBootstrapAccountPassword = mapped
    }

    /**
     * @param value Cluster operator account password.
     */
    @JvmName("mdylrhovtmrfkdcu")
    public suspend fun clusterOperatorAccountPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterOperatorAccountPassword = mapped
    }

    /**
     * @param value SQL service account password.
     */
    @JvmName("wpuxsvxaxivtebqv")
    public suspend fun sqlServiceAccountPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlServiceAccountPassword = mapped
    }

    internal fun build(): WsfcDomainCredentialsArgs = WsfcDomainCredentialsArgs(
        clusterBootstrapAccountPassword = clusterBootstrapAccountPassword,
        clusterOperatorAccountPassword = clusterOperatorAccountPassword,
        sqlServiceAccountPassword = sqlServiceAccountPassword,
    )
}
